/* robustness.do: Robustness Analysis */
/**** Sadoff et al. (2019) ***/
/***  This file provides the results from the robustness section and is called by doanalysis.do ***/



/***** BEGIN ROBUSTNESS ANALYSIS *****/

log on
/* Correlates and Stability of Inconsistency */
corr inconsistentnocommit inconsistentcommit if obsnum ==1 & attrit == 0 & evercommit == 0 
corr inconsistentr1 inconsistentr2 if obsnum ==1 & attrit == 0
corr inconsistentnocommit nokids if obsnum ==1 & attrit == 0
corr inconsistentr1 morekids if obsnum ==1 & attrit == 0
corr inconsistentr1 morehungry if obsnum ==1 & attrit == 0
corr inconsistentr1 moreinsecure if obsnum ==1 & attrit == 0
corr inconsistentr1 lesssnap if obsnum ==1 & attrit == 0 & snapenrolled == 1


/* Correlates and Stability of Commitment */
corr law2commit commit if obsnum == 1 & attrit == 0
pwcorr law2commit commit if obsnum == 1 & attrit == 0, sig
log off


/*** Complementarities ***/
/* Cobb Douglas Utility with h^a*(g^(1-a)) */
/* Marginal condition g/h = (1-a)/a at price 1 */
/* a = 1/((g/h) + 1) */

capture drop ratio
gen ratio = (1-prophealthy)/prophealthy

capture drop alpha
gen alpha =  1/(ratio+1)


capture drop alphai_imm 
capture drop alphai_adv
capture drop temp
egen temp = mean(alpha) if immediate == 0 & commitavail == 0 & attrit ==0, by(uniqidround)
egen alphai_adv = mean(temp), by(uniqidround)
capture drop temp
egen temp = mean(alpha) if immediate == 1 & commitavail == 0 & attrit ==0, by(uniqidround)
egen alphai_imm = mean(temp), by(uniqidround)


/* Utility Values for Bundles */
capture drop utility_adv
capture drop utility_imm
gen utility_adv = (bundlehealthy^alphai_adv)*(totalchosen-bundlehealthy)^(1-alphai_adv) 
gen utility_imm = (bundlehealthy^alphai_imm)*(totalchosen-bundlehealthy)^(1-alphai_imm) 


capture drop temp
egen temp = mean(utility_adv) if immediate == 1 & commitavail == 0 & attrit ==0, by(uniqidround)
capture drop utility_adv_imm
egen utility_adv_imm = mean(temp), by(uniqidround)


capture drop temp
egen temp = mean(utility_adv) if immediate == 0 & commitavail == 0 & attrit ==0, by(uniqidround)
capture drop utility_adv_adv
egen utility_adv_adv = mean(temp), by(uniqidround)

capture drop temp
egen temp = mean(utility_imm) if immediate == 1 & commitavail == 0 & attrit ==0, by(uniqidround)
capture drop utility_imm_imm
egen utility_imm_imm = mean(temp), by(uniqidround)

capture drop temp
egen temp = mean(utility_imm) if immediate == 0 & commitavail == 0 & attrit ==0, by(uniqidround)
capture drop utility_imm_adv
egen utility_imm_adv = mean(temp), by(uniqidround)


/* Equivalent Variation */
capture drop ev_adv
gen ev_adv = 10 - ((utility_adv_imm)/((alphai_adv^alphai_adv)*((1-alphai_adv)^(1-alphai_adv))))

capture drop ev_imm
gen ev_imm = 10 - ((utility_imm_adv)/((alphai_imm^alphai_imm)*((1-alphai_imm)^(1-alphai_imm))))

/* Usable Sample */
capture drop sample 
gen sample = 0
replace sample = 1 if (obsnum ==1 | obsnum==21 | obsnum == 41|obsnum == 61) & commitavail == 0 & alphai_adv != 1 &  alphai_imm != 1 & attrit == 0 & inconsistent == 1

log on
/* Reported Statistics for Complementarities ***/
su alphai_adv if sample ==1 & immediate == 1, det
su alphai_imm  if sample ==1 & immediate == 1, det

su ev_adv if sample ==1 & immediate == 1, det
su ev_imm if sample ==1 & immediate == 1, det
log off


/***** END ROBUSTNESS ANALYSIS *****/

